@@ -7,8 +7,8 @@ fn can_use_two_dimensions() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![
-                create_delivery_job_with_demand("job1", vec![1., 0.], vec![0, 1]),
-                create_delivery_job_with_demand("job2", vec![2., 0.], vec![1, 0]),
+                create_delivery_job_with_demand("job1", (1., 0.), vec![0, 1]),
+                create_delivery_job_with_demand("job2", (2., 0.), vec![1, 0]),
             ],
             ..create_empty_plan()
         },
@@ -80,10 +80,7 @@ fn can_use_two_dimensions() {
 #[test]
 fn can_unassign_due_to_dimension_mismatch() {
     let problem = Problem {
-        plan: Plan {
-            jobs: vec![create_delivery_job_with_demand("job1", vec![1., 0.], vec![0, 1])],
-            ..create_empty_plan()
-        },
+        plan: Plan { jobs: vec![create_delivery_job_with_demand("job1", (1., 0.), vec![0, 1])], ..create_empty_plan() },
         fleet: Fleet {
             vehicles: vec![VehicleType {
                 shifts: vec![create_default_open_vehicle_shift()],
@@ -101,12 +98,7 @@ fn can_unassign_due_to_dimension_mismatch() {
     assert_eq!(
         solution,
         Solution {
-            statistic: Statistic {
-                cost: 0.,
-                distance: 0,
-                duration: 0,
-                times: Timing { driving: 0, serving: 0, ..Timing::default() },
-            },
+            statistic: Statistic::default(),
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
                 job_id: "job1".to_string(),
