@@ -5,7 +5,7 @@ use crate::helpers::*;
 #[test]
 fn can_use_vehicle_with_open_end() {
     let problem = Problem {
-        plan: Plan { jobs: vec![create_delivery_job("job1", vec![1., 0.])], ..create_empty_plan() },
+        plan: Plan { jobs: vec![create_delivery_job("job1", (1., 0.))], ..create_empty_plan() },
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
         ..create_empty_problem()
     };
@@ -22,12 +22,7 @@ fn can_use_vehicle_with_open_end() {
     assert_eq!(
         solution,
         Solution {
-            statistic: Statistic {
-                cost: 0.,
-                distance: 0,
-                duration: 0,
-                times: Timing { driving: 0, serving: 0, ..Timing::default() },
-            },
+            statistic: Statistic::default(),
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
                 job_id: "job1".to_string(),
