@@ -7,9 +7,9 @@ fn can_use_one_pickup_delivery_and_two_deliveries_with_one_vehicle() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![
-                create_delivery_job("job1", vec![1., 0.]),
-                create_pickup_delivery_job("job2", vec![2., 0.], vec![3., 0.]),
-                create_delivery_job("job3", vec![4., 0.]),
+                create_delivery_job("job1", (1., 0.)),
+                create_pickup_delivery_job("job2", (2., 0.), (3., 0.)),
+                create_delivery_job("job3", (4., 0.)),
             ],
             ..create_empty_plan()
         },
