@@ -1,13 +1,14 @@
 use crate::format::problem::*;
 use crate::format::solution::*;
+use crate::format_time;
 use crate::helpers::*;
 
 fn create_test_plan_with_three_jobs() -> Plan {
     Plan {
         jobs: vec![
-            create_delivery_job_with_order("job1", vec![2., 0.], 2),
-            create_delivery_job_with_order("job2", vec![5., 0.], 1),
-            create_delivery_job("job3", vec![7., 0.]),
+            create_delivery_job_with_order("job1", (2., 0.), 2),
+            create_delivery_job_with_order("job2", (5., 0.), 1),
+            create_delivery_job("job3", (7., 0.)),
         ],
         ..create_empty_plan()
     }
@@ -17,11 +18,21 @@ fn create_test_limit() -> Option<VehicleLimits> {
     Some(VehicleLimits { max_distance: Some(15.), shift_time: None, tour_size: None, areas: None })
 }
 
+fn create_prioritized_objective() -> Vec<Vec<Objective>> {
+    vec![
+        vec![Objective::MinimizeUnassignedJobs { breaks: None }],
+        vec![Objective::MinimizeTours {}],
+        vec![Objective::TourOrder { is_constrained: true }],
+        vec![Objective::MinimizeCost],
+    ]
+}
+
 #[test]
 fn can_follow_orders() {
     let problem = Problem {
         plan: create_test_plan_with_three_jobs(),
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
+        objectives: Some(create_prioritized_objective()),
         ..create_empty_problem()
     };
     let matrix = create_matrix_from_problem(&problem);
@@ -122,12 +133,7 @@ fn can_follow_order_when_prioritized_property_set() {
             vehicles: vec![VehicleType { limits: create_test_limit(), ..create_default_vehicle_type() }],
             profiles: create_default_matrix_profiles(),
         },
-        objectives: Some(vec![
-            vec![Objective::MinimizeUnassignedJobs { breaks: None }],
-            vec![Objective::MinimizeTours {}],
-            vec![Objective::TourOrder { is_constrained: true }],
-            vec![Objective::MinimizeCost],
-        ]),
+        objectives: Some(create_prioritized_objective()),
         ..create_empty_problem()
     };
     let matrix = create_matrix_from_problem(&problem);
@@ -146,3 +152,53 @@ fn can_follow_order_when_prioritized_property_set() {
         }])
     );
 }
+
+#[test]
+fn can_handle_order_between_special_activities() {
+    let create_test_job = |id: &str, location: (f64, f64), order: i32| Job {
+        deliveries: Some(vec![JobTask {
+            places: vec![JobPlace { times: None, location: location.to_loc(), duration: 100., tag: None }],
+            demand: Some(vec![1]),
+            order: Some(order),
+        }]),
+        ..create_job(id)
+    };
+    let problem = Problem {
+        plan: Plan {
+            jobs: vec![create_test_job("job1", (1., 0.), 2), create_test_job("job2", (2., 0.), 1)],
+            ..create_empty_plan()
+        },
+        fleet: Fleet {
+            vehicles: vec![VehicleType {
+                shifts: vec![VehicleShift {
+                    end: Some(ShiftEnd {
+                        earliest: None,
+                        latest: format_time(1000.).to_string(),
+                        location: (10., 0.).to_loc(),
+                    }),
+                    breaks: Some(vec![VehicleBreak::Optional {
+                        time: VehicleOptionalBreakTime::TimeWindow(vec![format_time(100.), format_time(200.)]),
+                        places: vec![VehicleOptionalBreakPlace {
+                            duration: 1.,
+                            location: Some((0., 0.).to_loc()),
+                            tag: None,
+                        }],
+                        policy: Some(VehicleOptionalBreakPolicy::SkipIfNoIntersection),
+                    }]),
+                    ..create_default_vehicle_shift()
+                }],
+                ..create_default_vehicle_type()
+            }],
+            profiles: create_default_matrix_profiles(),
+        },
+        ..create_empty_problem()
+    };
+    let matrix = create_matrix_from_problem(&problem);
+
+    let solution = solve_with_metaheuristic(problem, Some(vec![matrix]));
+
+    assert_eq!(
+        get_ids_from_tour(&solution.tours[0]),
+        vec![vec!["departure"], vec!["job2"], vec!["break"], vec!["job1"], vec!["arrival"]]
+    );
+}
