@@ -8,7 +8,7 @@ fn can_wait_for_job_start() {
         plan: Plan {
             jobs: vec![create_delivery_job_with_skills(
                 "job1",
-                vec![1., 0.],
+                (1., 0.),
                 all_of_skills(vec!["unique_skill".to_string()]),
             )],
             ..create_empty_plan()
