@@ -8,7 +8,7 @@ fn can_have_unassigned_due_to_missing_vehicle_skill() {
         plan: Plan {
             jobs: vec![create_delivery_job_with_skills(
                 "job1",
-                vec![1., 0.],
+                (1., 0.),
                 all_of_skills(vec!["unique_skill".to_string()]),
             )],
             ..create_empty_plan()
@@ -26,12 +26,7 @@ fn can_have_unassigned_due_to_missing_vehicle_skill() {
     assert_eq!(
         solution,
         Solution {
-            statistic: Statistic {
-                cost: 0.,
-                distance: 0,
-                duration: 0,
-                times: Timing { driving: 0, serving: 0, ..Timing::default() },
-            },
+            statistic: Statistic::default(),
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
                 job_id: "job1".to_string(),
