@@ -1,5 +1,6 @@
 use crate::extensions::create_typed_actor_groups;
 use std::sync::Arc;
+use vrp_core::construction::constraints::ConstraintPipeline;
 use vrp_core::construction::heuristics::InsertionContext;
 use vrp_core::construction::heuristics::{RegistryContext, SolutionContext};
 use vrp_core::models::common::*;
@@ -81,6 +82,14 @@ pub fn create_single(id: &str) -> Arc<Single> {
     Arc::new(single)
 }
 
+pub fn create_single_with_type(id: &str, activity_type: &str) -> Arc<Single> {
+    let mut single = create_single_with_location(Some(DEFAULT_JOB_LOCATION));
+    single.dimens.set_id(id);
+    single.dimens.set_value("type", activity_type.to_string());
+
+    Arc::new(single)
+}
+
 pub fn create_single_with_location(location: Option<Location>) -> Single {
     Single {
         places: vec![vrp_core::models::problem::Place {
@@ -105,6 +114,7 @@ pub fn single_demand_as_multi(pickup: (i32, i32), delivery: (i32, i32)) -> Deman
 }
 
 pub fn create_solution_context_for_fleet(fleet: &Fleet) -> SolutionContext {
+    let constraint = Arc::new(ConstraintPipeline::default());
     SolutionContext {
         required: vec![],
         ignored: vec![],
@@ -112,7 +122,7 @@ pub fn create_solution_context_for_fleet(fleet: &Fleet) -> SolutionContext {
         locked: Default::default(),
         state: Default::default(),
         routes: Default::default(),
-        registry: RegistryContext::new(Registry::new(&fleet, Arc::new(DefaultRandom::default()))),
+        registry: RegistryContext::new(constraint, Registry::new(&fleet, Arc::new(DefaultRandom::default()))),
     }
 }
 
