@@ -129,12 +129,12 @@ fn can_handle_properly_invalid_break_removal() {
                             location: Location::Coordinate { lat: 52.44105158292253, lng: 13.424429791168873 },
                         }),
                         dispatch: None,
-                        breaks: Some(vec![VehicleBreak {
-                            time: VehicleBreakTime::TimeWindow(vec![
+                        breaks: Some(vec![VehicleBreak::Optional {
+                            time: VehicleOptionalBreakTime::TimeWindow(vec![
                                 "2020-07-04T12:00:00Z".to_string(),
                                 "2020-07-04T14:00:00Z".to_string(),
                             ]),
-                            places: vec![VehicleBreakPlace { duration: 3600.0, location: None, tag: None }],
+                            places: vec![VehicleOptionalBreakPlace { duration: 3600.0, location: None, tag: None }],
                             policy: None,
                         }]),
                         reloads: None,
